"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const superagent = require("superagent");
const ServiceClientBase_1 = require("./ServiceClientBase");
const errors = require("../errors");
class SyncClient extends ServiceClientBase_1.ServiceClientBase {
    constructor() {
        super(...arguments);
        this.serviceName = "sync";
        this.baseRoute = undefined;
    }
    deleteRealm(realmPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const service = yield this.findService();
            if (!service) {
                throw new errors.realm.ServiceUnavailable({ detail: "Could not discover sync service" });
            }
            const route = this.getServiceRoute(service)
                .segment(["api", "realm", realmPath])
                .toString();
            const request = superagent.delete(route);
            return this.executeRequest(request, { token: this.authorizationHeader(), retryOn404: false });
        });
    }
    compactRealms() {
        return __awaiter(this, void 0, void 0, function* () {
            const services = yield this.findAllServices();
            if (services.length === 0) {
                throw new errors.realm.ServiceUnavailable({ detail: "Could not discover sync service" });
            }
            const responses = services.map((service) => {
                const route = this.getServiceRoute(service)
                    .segment(["api", "compact"])
                    .toString();
                const request = superagent.post(route);
                return this.executeRequest(request, { token: this.authorizationHeader() });
            });
            yield Promise.all(responses);
        });
    }
    calculateSize(realmPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const services = yield this.findAllServices();
            if (services.length === 0) {
                throw new errors.realm.ServiceUnavailable();
            }
            const responses = services.map((service) => {
                const route = this.getServiceRoute(service)
                    .segment(["report-realm-state-size", realmPath])
                    .toString();
                const request = superagent.post(route);
                return this.executeRequest(request, { token: this.authorizationHeader() });
            });
            yield Promise.all(responses);
        });
    }
    compactRealm(realmPath) {
        return __awaiter(this, void 0, void 0, function* () {
            const handle = yield this.findService();
            const route = this.getServiceRoute(handle)
                .segment(["api", "compact", realmPath])
                .toString();
            yield this.executeRequest(superagent.post(route), { token: this.authorizationHeader() });
        });
    }
    authorizationHeader() {
        return `Realm-Access-Token version=1 token="${this.adminToken}"`;
    }
}
exports.SyncClient = SyncClient;
//# sourceMappingURL=SyncClient.js.map